Struct MainLoop

pub struct MainLoop(/* private fields */);
Transparent wrapper around a main loop.

This does not own the underlying object and is usually seen behind a & reference.

For owning wrappers that can construct main loops, see MainLoopBox and MainLoopRc.

For an explanation of these, see Smart pointers to PipeWire objects.

Implementations

Source

impl MainLoop

pub fn as_raw(&self) -> &pw_main_loop

pub fn as_raw_ptr(&self) -> *mut pw_main_loop

pub fn loop_(&self) -> &Loop

pub fn run(&self)

pub fn quit(&self)