pub struct MainLoop(/* private fields */);Expand description
Transparent wrapper around a main loop.
This does not own the underlying object and is usually seen behind a & reference.
For owning wrappers that can construct main loops, see MainLoopBox and MainLoopRc.
For an explanation of these, see Smart pointers to PipeWire objects.
Implementations